==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebStepDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebStepDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebStepDescription, _super);
    function WebStepDescription() {
        var _this = _super.call(this) || this;
        _this.j = false;
        _this.f = false;
        _this.l = false;
        _this.i = false;
        _this.g = false;
        _this.m = false;
        _this.aa = null;
        _this.ab = null;
        _this.z = null;
        _this.x = 0;
        _this.h = false;
        _this.k = false;
        _this.n = false;
        return _this;
    }
    WebStepDescription.prototype.get_type = function () {
        return "WebStep";
    };
    Object.defineProperty(WebStepDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "invalid", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.e("Invalid");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "active", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Active");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "optional", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.e("Optional");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "disabled", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.e("Disabled");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "complete", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("Complete");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "previousComplete", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.e("PreviousComplete");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "stepType", {
        get: function () {
            return this.aa;
        },
        set: function (a) {
            this.aa = a;
            this.e("StepType");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "titlePosition", {
        get: function () {
            return this.ab;
        },
        set: function (a) {
            this.ab = a;
            this.e("TitlePosition");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "orientation", {
        get: function () {
            return this.z;
        },
        set: function (a) {
            this.z = a;
            this.e("Orientation");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "index", {
        get: function () {
            return this.x;
        },
        set: function (a) {
            this.x = a;
            this.e("Index");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "contentTop", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("ContentTop");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "linearDisabled", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e("LinearDisabled");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "visited", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.e("Visited");
        },
        enumerable: true,
        configurable: true
    });
    WebStepDescription.$t = markType(WebStepDescription, 'WebStepDescription', Description.$);
    return WebStepDescription;
}(Description));
export { WebStepDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebStepDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebStepDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebStepDescription, _super);
    function WebStepDescription() {
        var _this = _super.call(this) || this;
        _this.k = false;
        _this.h = false;
        _this.l = false;
        _this.j = false;
        _this.i = false;
        return _this;
    }
    WebStepDescription.prototype.get_type = function () {
        return "WebStep";
    };
    Object.defineProperty(WebStepDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "invalid", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.g("Invalid");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "active", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Active");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "optional", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.g("Optional");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "disabled", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("Disabled");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebStepDescription.prototype, "complete", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("Complete");
        },
        enumerable: false,
        configurable: true
    });
    WebStepDescription.$t = markType(WebStepDescription, 'WebStepDescription', Description.$);
    return WebStepDescription;
}(Description));
export { WebStepDescription };
